@@ -1,7 +1,9 @@
 package Perinci::Sub::XCompletion::date_dow_nums;
 
-our $DATE = '2021-07-19'; # DATE
-our $VERSION = '0.014'; # VERSION
+our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
+our $DATE = '2021-08-04'; # DATE
+our $DIST = 'Sah-Schemas-Date'; # DIST
+our $VERSION = '0.015'; # VERSION
 
 use 5.010001;
 use strict;
@@ -45,7 +47,7 @@ Perinci::Sub::XCompletion::date_dow_nums - Generate completion for date::dow_num
 
 =head1 VERSION
 
-This document describes version 0.014 of Perinci::Sub::XCompletion::date_dow_nums (from Perl distribution Sah-Schemas-Date), released on 2021-07-19.
+This document describes version 0.015 of Perinci::Sub::XCompletion::date_dow_nums (from Perl distribution Sah-Schemas-Date), released on 2021-08-04.
 
 =head1 CONFIGURATION
 
