@@ -1,28 +1,36 @@
 package Sah::Schema::date::dow_num;
 
 our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
-our $DATE = '2021-07-19'; # DATE
+our $DATE = '2021-08-04'; # DATE
 our $DIST = 'Sah-Schemas-Date'; # DIST
-our $VERSION = '0.014'; # VERSION
+our $VERSION = '0.015'; # VERSION
 
 our $schema = [int => {
-    summary => 'Day-of-week number (1-7, 1=Monday)',
+    summary => 'Day-of-week number (1-7, 1=Monday, like DateTime), coercible from English day-of-week name (Mo/mon/MONDAY)',
     min => 1,
     max => 7,
     'x.perl.coerce_rules' => ['From_str::convert_en_dow_name_to_num'],
     'x.completion' => ['date_dow_num'],
+    description => <<'_',
+
+See also related schemas that coerce from other locales, e.g.
+<pm:Sah::Schema::date::dow_num::id> (Indonesian),
+<pm:Sah::Schema::date::dow_num::en_or_id> (English/Indonesian), etc.
+
+_
     examples => [
-        {value=>'', valid=>0},
-        {value=>0, valid=>0},
+        {value=>'', valid=>0, summary=>"Not in 1-7"},
+        {value=>0, valid=>0, summary=>"Not in 1-7"},
         {value=>1, valid=>1},
+        {value=>"Tue", validated_value=>2, valid=>1},
         {value=>7, valid=>1},
-        {value=>8, valid=>0},
+        {value=>8, valid=>0, summary=>"Not in 1-7"},
     ],
-}, {}];
+}];
 
 1;
 
-# ABSTRACT: Day-of-week number (1-7, 1=Monday)
+# ABSTRACT: Day-of-week number (1-7, 1=Monday, like DateTime), coercible from English day-of-week name (Mo/mon/MONDAY)
 
 __END__
 
@@ -32,11 +40,11 @@ __END__
 
 =head1 NAME
 
-Sah::Schema::date::dow_num - Day-of-week number (1-7, 1=Monday)
+Sah::Schema::date::dow_num - Day-of-week number (1-7, 1=Monday, like DateTime), coercible from English day-of-week name (Mo/mon/MONDAY)
 
 =head1 VERSION
 
-This document describes version 0.014 of Sah::Schema::date::dow_num (from Perl distribution Sah-Schemas-Date), released on 2021-07-19.
+This document describes version 0.015 of Sah::Schema::date::dow_num (from Perl distribution Sah-Schemas-Date), released on 2021-08-04.
 
 =head1 SYNOPSIS
 
@@ -90,7 +98,7 @@ L<Perinci::CmdLine> to create a CLI:
  package
    main;
  use Perinci::CmdLine::Any;
- Perinci::CmdLine::Any->new(url=>'MyApp::myfunc')->run;
+ Perinci::CmdLine::Any->new(url=>'/MyApp/myfunc')->run;
 
  # in command-line
  % ./myapp.pl --help
@@ -103,15 +111,23 @@ L<Perinci::CmdLine> to create a CLI:
 
 Sample data:
 
- ""  # INVALID
+ ""  # INVALID (Not in 1-7)
 
- 0  # INVALID
+ 0  # INVALID (Not in 1-7)
 
  1  # valid
 
+ "Tue"  # valid, becomes 2
+
  7  # valid
 
- 8  # INVALID
+ 8  # INVALID (Not in 1-7)
+
+=head1 DESCRIPTION
+
+See also related schemas that coerce from other locales, e.g.
+L<Sah::Schema::date::dow_num::id> (Indonesian),
+L<Sah::Schema::date::dow_num::en_or_id> (English/Indonesian), etc.
 
 =head1 HOMEPAGE
 
