@@ -1,25 +1,25 @@
 package Sah::Schema::date::minute;
 
 our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
-our $DATE = '2021-07-19'; # DATE
+our $DATE = '2021-08-04'; # DATE
 our $DIST = 'Sah-Schemas-Date'; # DIST
-our $VERSION = '0.014'; # VERSION
+our $VERSION = '0.015'; # VERSION
 
 our $schema = [int => {
-    summary => 'Minute of hour',
+    summary => 'Minute of hour (0-59)',
     min     => 0,
     max     => 59,
     examples => [
-        {value=>'', valid=>0},
+        {value=>'', valid=>0, summary=>'Empty string'},
         {value=>0, valid=>1},
         {value=>59, valid=>1},
-        {value=>60, valid=>0},
+        {value=>60, valid=>0, summary=>'Not in 0-59'},
     ],
-}, {}];
+}];
 
 1;
 
-# ABSTRACT: Minute of hour
+# ABSTRACT: Minute of hour (0-59)
 
 __END__
 
@@ -29,11 +29,11 @@ __END__
 
 =head1 NAME
 
-Sah::Schema::date::minute - Minute of hour
+Sah::Schema::date::minute - Minute of hour (0-59)
 
 =head1 VERSION
 
-This document describes version 0.014 of Sah::Schema::date::minute (from Perl distribution Sah-Schemas-Date), released on 2021-07-19.
+This document describes version 0.015 of Sah::Schema::date::minute (from Perl distribution Sah-Schemas-Date), released on 2021-08-04.
 
 =head1 SYNOPSIS
 
@@ -87,7 +87,7 @@ L<Perinci::CmdLine> to create a CLI:
  package
    main;
  use Perinci::CmdLine::Any;
- Perinci::CmdLine::Any->new(url=>'MyApp::myfunc')->run;
+ Perinci::CmdLine::Any->new(url=>'/MyApp/myfunc')->run;
 
  # in command-line
  % ./myapp.pl --help
@@ -100,13 +100,13 @@ L<Perinci::CmdLine> to create a CLI:
 
 Sample data:
 
- ""  # INVALID
+ ""  # INVALID (Empty string)
 
  0  # valid
 
  59  # valid
 
- 60  # INVALID
+ 60  # INVALID (Not in 0-59)
 
 =head1 HOMEPAGE
 
