@@ -1,9 +1,9 @@
 package Sah::Schema::date::month::en;
 
 our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
-our $DATE = '2021-07-19'; # DATE
+our $DATE = '2021-08-04'; # DATE
 our $DIST = 'Sah-Schemas-Date'; # DIST
-our $VERSION = '0.014'; # VERSION
+our $VERSION = '0.015'; # VERSION
 
 our $schema = [cistr => {
     summary => 'Month number/name (abbreviated or full, in English)',
@@ -12,16 +12,26 @@ our $schema = [cistr => {
         qw/jan feb mar apr may jun jul aug sep oct nov dec/,
         qw/january february march april june july august september october november december/,
     ],
+    description => <<'_',
+
+Note that name is not coerced to number; use
+<pm:Sah::Schema::date::month_num::id> for that.
+
+See also related schemas for other locales, e.g.
+<pm:Sah::Schema::date::month::id> (Indonesian),
+<pm:Sah::Schema::date::month::en_or_id> (English/Indonesian), etc.
+
+_
     examples => [
-        {value=>'', valid=>0},
+        {value=>'', valid=>0, summary=>'Empty string'},
         {value=>1, valid=>1},
         {value=>'jan', valid=>1},
         {value=>'FeB', valid=>1},
         {value=>'March', valid=>1},
-        {value=>'foo', valid=>0},
-        {value=>13, valid=>0},
+        {value=>'foo', valid=>0, summary=>'Not a month name/number'},
+        {value=>13, valid=>0, summary=>'Number not in 1-12'},
     ],
-}, {}];
+}];
 
 1;
 
@@ -39,7 +49,7 @@ Sah::Schema::date::month::en - Month number/name (abbreviated or full, in Englis
 
 =head1 VERSION
 
-This document describes version 0.014 of Sah::Schema::date::month::en (from Perl distribution Sah-Schemas-Date), released on 2021-07-19.
+This document describes version 0.015 of Sah::Schema::date::month::en (from Perl distribution Sah-Schemas-Date), released on 2021-08-04.
 
 =head1 SYNOPSIS
 
@@ -93,7 +103,7 @@ L<Perinci::CmdLine> to create a CLI:
  package
    main;
  use Perinci::CmdLine::Any;
- Perinci::CmdLine::Any->new(url=>'MyApp::myfunc')->run;
+ Perinci::CmdLine::Any->new(url=>'/MyApp/myfunc')->run;
 
  # in command-line
  % ./myapp.pl --help
@@ -106,7 +116,7 @@ L<Perinci::CmdLine> to create a CLI:
 
 Sample data:
 
- ""  # INVALID
+ ""  # INVALID (Empty string)
 
  1  # valid
 
@@ -116,9 +126,18 @@ Sample data:
 
  "March"  # valid
 
- "foo"  # INVALID
+ "foo"  # INVALID (Not a month name/number)
 
- 13  # INVALID
+ 13  # INVALID (Number not in 1-12)
+
+=head1 DESCRIPTION
+
+Note that name is not coerced to number; use
+L<Sah::Schema::date::month_num::id> for that.
+
+See also related schemas for other locales, e.g.
+L<Sah::Schema::date::month::id> (Indonesian),
+L<Sah::Schema::date::month::en_or_id> (English/Indonesian), etc.
 
 =head1 HOMEPAGE
 
