@@ -1,9 +1,9 @@
 package Sah::Schema::date::month_name::en;
 
 our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
-our $DATE = '2021-07-19'; # DATE
+our $DATE = '2021-08-04'; # DATE
 our $DIST = 'Sah-Schemas-Date'; # DIST
-our $VERSION = '0.014'; # VERSION
+our $VERSION = '0.015'; # VERSION
 
 our $schema = [cistr => {
     summary => 'Month name (abbreviated or full, in English)',
@@ -11,16 +11,25 @@ our $schema = [cistr => {
         qw/jan feb mar apr may jun jul aug sep oct nov dec/,
         qw/january february march april june july august september october november december/,
     ],
+    description => <<'_',
+
+See also: <pm:Sah::Schema::date::month_num>.
+
+See also related schemas for other locales, e.g.
+<pm:Sah::Schema::date::month_name::id> (Indonesian),
+<pm:Sah::Schema::date::month_name::en_or_id> (English/Indonesian), etc.
+
+_
     examples => [
-        {value=>'', valid=>0},
-        {value=>1, valid=>0},
+        {value=>'', valid=>0, summary=>'Empty string'},
+        {value=>1, valid=>0, summary=>'Not month name'},
         {value=>'jan', valid=>1},
         {value=>'FeB', valid=>1},
         {value=>'March', valid=>1},
-        {value=>'foo', valid=>0},
-        {value=>13, valid=>0},
+        {value=>'foo', valid=>0, summary=>'Unknown month name'},
+        {value=>13, valid=>0, summary=>'Not month name'},
     ],
-}, {}];
+}];
 
 1;
 
@@ -38,7 +47,7 @@ Sah::Schema::date::month_name::en - Month name (abbreviated or full, in English)
 
 =head1 VERSION
 
-This document describes version 0.014 of Sah::Schema::date::month_name::en (from Perl distribution Sah-Schemas-Date), released on 2021-07-19.
+This document describes version 0.015 of Sah::Schema::date::month_name::en (from Perl distribution Sah-Schemas-Date), released on 2021-08-04.
 
 =head1 SYNOPSIS
 
@@ -92,7 +101,7 @@ L<Perinci::CmdLine> to create a CLI:
  package
    main;
  use Perinci::CmdLine::Any;
- Perinci::CmdLine::Any->new(url=>'MyApp::myfunc')->run;
+ Perinci::CmdLine::Any->new(url=>'/MyApp/myfunc')->run;
 
  # in command-line
  % ./myapp.pl --help
@@ -105,9 +114,9 @@ L<Perinci::CmdLine> to create a CLI:
 
 Sample data:
 
- ""  # INVALID
+ ""  # INVALID (Empty string)
 
- 1  # INVALID
+ 1  # INVALID (Not month name)
 
  "jan"  # valid
 
@@ -115,9 +124,17 @@ Sample data:
 
  "March"  # valid
 
- "foo"  # INVALID
+ "foo"  # INVALID (Unknown month name)
 
- 13  # INVALID
+ 13  # INVALID (Not month name)
+
+=head1 DESCRIPTION
+
+See also: L<Sah::Schema::date::month_num>.
+
+See also related schemas for other locales, e.g.
+L<Sah::Schema::date::month_name::id> (Indonesian),
+L<Sah::Schema::date::month_name::en_or_id> (English/Indonesian), etc.
 
 =head1 HOMEPAGE
 
