@@ -1,30 +1,39 @@
 package Sah::Schema::date::month_nums;
 
 our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
-our $DATE = '2021-07-19'; # DATE
+our $DATE = '2021-08-04'; # DATE
 our $DIST = 'Sah-Schemas-Date'; # DIST
-our $VERSION = '0.014'; # VERSION
+our $VERSION = '0.015'; # VERSION
 
 our $schema = ['array' => {
-    summary => 'Array of month numbers',
-    of => ['date::month_num', {}, {}],
+    summary => 'Array of required month numbers (1-12, with coercions)',
+    of => ['date::month_num', {req=>1}],
     'x.perl.coerce_rules' => ['From_str::comma_sep'],
     'x.completion' => ['date_month_num'],
+    description => <<'_',
+
+See also related schemas that coerce from other locales, e.g.
+<pm:Sah::Schema::date::month_nums::id> (Indonesian),
+<pm:Sah::Schema::date::month_nums::en_or_id> (English/Indonesian), etc.
+
+_
     examples => [
         {value=>'', valid=>1, validated_value=>[]},
-        {value=>0, valid=>0},
+        {value=>0, valid=>0, summary=>'Has number not in 1-12'},
         {value=>1, valid=>1, validated_value=>[1]},
         {value=>[1], valid=>1},
         {value=>[1,12], valid=>1},
-        {value=>'1,12', valid=>1, validated_value=>[1,12]},
-        {value=>[1,12,13], valid=>0},
-        {value=>'1,12,13', valid=>0},
+        {value=>[1,undef], valid=>0, summary=>'Contains undef'},
+        {value=>["Jan","JUN"], validated_value=>[1,6], valid=>1},
+        {value=>'January,JUNE', valid=>1, validated_value=>[1,6]},
+        {value=>[1,12,13], valid=>0, summary=>'Has number not in 1-12'},
+        {value=>'1,12,13', valid=>0, summary=>'Has number not in 1-12'},
     ],
-}, {}];
+}];
 
 1;
 
-# ABSTRACT: Array of month numbers
+# ABSTRACT: Array of required month numbers (1-12, with coercions)
 
 __END__
 
@@ -34,11 +43,11 @@ __END__
 
 =head1 NAME
 
-Sah::Schema::date::month_nums - Array of month numbers
+Sah::Schema::date::month_nums - Array of required month numbers (1-12, with coercions)
 
 =head1 VERSION
 
-This document describes version 0.014 of Sah::Schema::date::month_nums (from Perl distribution Sah-Schemas-Date), released on 2021-07-19.
+This document describes version 0.015 of Sah::Schema::date::month_nums (from Perl distribution Sah-Schemas-Date), released on 2021-08-04.
 
 =head1 SYNOPSIS
 
@@ -92,7 +101,7 @@ L<Perinci::CmdLine> to create a CLI:
  package
    main;
  use Perinci::CmdLine::Any;
- Perinci::CmdLine::Any->new(url=>'MyApp::myfunc')->run;
+ Perinci::CmdLine::Any->new(url=>'/MyApp/myfunc')->run;
 
  # in command-line
  % ./myapp.pl --help
@@ -107,7 +116,7 @@ Sample data:
 
  ""  # valid, becomes []
 
- 0  # INVALID
+ 0  # INVALID (Has number not in 1-12)
 
  1  # valid, becomes [1]
 
@@ -115,11 +124,21 @@ Sample data:
 
  [1,12]  # valid
 
- "1,12"  # valid, becomes [1,12]
+ [1,undef]  # INVALID (Contains undef)
 
- [1,12,13]  # INVALID
+ ["Jan","JUN"]  # valid, becomes [1,6]
 
- "1,12,13"  # INVALID
+ "January,JUNE"  # valid, becomes [1,6]
+
+ [1,12,13]  # INVALID (Has number not in 1-12)
+
+ "1,12,13"  # INVALID (Has number not in 1-12)
+
+=head1 DESCRIPTION
+
+See also related schemas that coerce from other locales, e.g.
+L<Sah::Schema::date::month_nums::id> (Indonesian),
+L<Sah::Schema::date::month_nums::en_or_id> (English/Indonesian), etc.
 
 =head1 HOMEPAGE
 
