@@ -1,12 +1,17 @@
 package Sah::Schema::date::tz_name;
 
 our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
-our $DATE = '2021-07-19'; # DATE
+our $DATE = '2021-08-04'; # DATE
 our $DIST = 'Sah-Schemas-Date'; # DIST
-our $VERSION = '0.014'; # VERSION
+our $VERSION = '0.015'; # VERSION
 
 our $schema = [str => {
-    summary => 'Timezone name',
+    summary => 'Timezone name, e.g. Asia/Jakarta',
+    description => <<'_',
+
+Currently no validation for valid timezone names. But completion is provided.
+
+_
     'x.completion' => sub {
         require Complete::TZ;
 
@@ -17,11 +22,11 @@ our $schema = [str => {
     examples => [
         {value=>'Asia/Jakarta', valid=>1},
     ],
-}, {}];
+}];
 
 1;
 
-# ABSTRACT: Timezone name
+# ABSTRACT: Timezone name, e.g. Asia/Jakarta
 
 __END__
 
@@ -31,11 +36,11 @@ __END__
 
 =head1 NAME
 
-Sah::Schema::date::tz_name - Timezone name
+Sah::Schema::date::tz_name - Timezone name, e.g. Asia/Jakarta
 
 =head1 VERSION
 
-This document describes version 0.014 of Sah::Schema::date::tz_name (from Perl distribution Sah-Schemas-Date), released on 2021-07-19.
+This document describes version 0.015 of Sah::Schema::date::tz_name (from Perl distribution Sah-Schemas-Date), released on 2021-08-04.
 
 =head1 SYNOPSIS
 
@@ -89,7 +94,7 @@ L<Perinci::CmdLine> to create a CLI:
  package
    main;
  use Perinci::CmdLine::Any;
- Perinci::CmdLine::Any->new(url=>'MyApp::myfunc')->run;
+ Perinci::CmdLine::Any->new(url=>'/MyApp/myfunc')->run;
 
  # in command-line
  % ./myapp.pl --help
