@@ -1,23 +1,26 @@
 package Sah::Schema::date::year;
 
 our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
-our $DATE = '2021-07-19'; # DATE
+our $DATE = '2021-08-04'; # DATE
 our $DIST = 'Sah-Schemas-Date'; # DIST
-our $VERSION = '0.014'; # VERSION
+our $VERSION = '0.015'; # VERSION
 
 our $schema = [int => {
-    summary => 'Year number',
+    min => 1,
+    summary => 'Year number (AD, starting from 1)',
     examples => [
-        {value=>'', valid=>0},
+        {value=>'', valid=>0, summary=>'Empty string'},
+        {value=>0, valid=>0, summary=>'There is no AD 0; AD starts from 1'},
         {value=>1, valid=>1},
-        {value=>2020, valid=>1},
-        {value=>1.1, valid=>0},
+        {value=>2021, valid=>1},
+        {value=>10000, valid=>1},
+       {value=>1.1, valid=>0, summary=>'Not an integer'},
     ],
-}, {}];
+}];
 
 1;
 
-# ABSTRACT: Year number
+# ABSTRACT: Year number (AD, starting from 1)
 
 __END__
 
@@ -27,11 +30,11 @@ __END__
 
 =head1 NAME
 
-Sah::Schema::date::year - Year number
+Sah::Schema::date::year - Year number (AD, starting from 1)
 
 =head1 VERSION
 
-This document describes version 0.014 of Sah::Schema::date::year (from Perl distribution Sah-Schemas-Date), released on 2021-07-19.
+This document describes version 0.015 of Sah::Schema::date::year (from Perl distribution Sah-Schemas-Date), released on 2021-08-04.
 
 =head1 SYNOPSIS
 
@@ -85,7 +88,7 @@ L<Perinci::CmdLine> to create a CLI:
  package
    main;
  use Perinci::CmdLine::Any;
- Perinci::CmdLine::Any->new(url=>'MyApp::myfunc')->run;
+ Perinci::CmdLine::Any->new(url=>'/MyApp/myfunc')->run;
 
  # in command-line
  % ./myapp.pl --help
@@ -98,13 +101,17 @@ L<Perinci::CmdLine> to create a CLI:
 
 Sample data:
 
- ""  # INVALID
+ ""  # INVALID (Empty string)
+
+ 0  # INVALID (There is no AD 0; AD starts from 1)
 
  1  # valid
 
- 2020  # valid
+ 2021  # valid
 
- 1.1  # INVALID
+ 10000  # valid
+
+ 1.1  # INVALID (Not an integer)
 
 =head1 HOMEPAGE
 
